@@ -14,7 +14,7 @@ def change(node1, node2):
     del bid
 
 
-class Queue:
+class Queue(object):
     def __init__(self):
         self.__front = None
         self.__back = None
@@ -22,9 +22,9 @@ class Queue:
     def __str__(self):
         q = "Queue : ["
         tmp = self.__front
-        while tmp is not None:
+        while tmp:
             q += str(tmp.data)
-            if tmp.next is not None:
+            if tmp.next:
                 q += " | "
             tmp = tmp.next
         return q + "]"
@@ -32,7 +32,7 @@ class Queue:
     def __len__(self):
         size = 0
         tmp = self.__front
-        while tmp is not None:
+        while tmp:
             size += 1
             tmp = tmp.next
         return size
@@ -78,7 +78,7 @@ class Queue:
     def find(self, data):
         count = 0
         tmp = self.__front
-        while tmp is not None:
+        while tmp:
             if tmp.data == data:
                 count += 1
             tmp = tmp.next
@@ -95,8 +95,8 @@ class Queue:
     def sort(self):
         tmp1 = self.__front
         tmp2 = tmp1.next
-        while tmp1.next is not None:
-            while tmp2 is not None:
+        while tmp1.next:
+            while tmp2:
                 if tmp1.data > tmp2.data:
                     change(tmp1, tmp2)
                 tmp2 = tmp2.next
@@ -114,10 +114,10 @@ class Queue:
             que = Queue()
             tmp1 = q1.__front
             tmp2 = q2.__front
-            while tmp1 is not None:
+            while tmp1:
                 que.enqueue(tmp1.data)
                 tmp1 = tmp1.next
-            while tmp2 is not None:
+            while tmp2:
                 que.enqueue(tmp2.data)
                 tmp2 = tmp2.next
             del tmp1, tmp2
